@@ -90,6 +90,9 @@ def main(ctx, project, timeout, verbose):
 
     config = Config()
 
+    if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND:
+        project = git.get_root_folder(project)
+
     if ctx.invoked_subcommand not in ALLOW_NO_GIT_SUBCOMMAND and not git.is_repo(
         project
     ):
