@@ -111,8 +111,7 @@ class QainitHandler:
             f"/api/v1/qa/{qa_hash}",
             body=json.dumps(body),
         )
-        logger.info("QA update initiated")
-        logger.debug(json.dumps(r.json(), indent=2))
+        self.handle_call_result(r, "update", qa_hash)
 
     def list(self, params, page=1, page_size=10):
         filters = []
@@ -135,12 +134,12 @@ class QainitHandler:
         )
 
     def delete(self, qa_hash, force=False):
-        delete = self._execute(
+        r = self._execute(
             "DELETE",
             f"/api/v1/qa/{qa_hash}",
         )
-        logger.debug(json.dumps(delete.json(), indent=2))
-        if 200 <= delete.status_code <= 299:
+        logger.debug(json.dumps(r.json(), indent=2))
+        if r.ok:
             logger.info(f"QA {qa_hash} deletion initiated")
         else:
             logger.error(
@@ -190,15 +189,13 @@ class QainitHandler:
         body = {"operation": "freeze"}
         logger.debug(json.dumps(body))
         r = self._execute("PUT", f"/api/v1/qa/{qa_hash}", body=json.dumps(body))
-        logger.info("QA freezing initiated")
-        logger.debug(json.dumps(r.json(), indent=2))
+        self.handle_call_result(r, "freezing", qa_hash)
 
     def unfreeze(self, qa_hash):
         body = {"operation": "unfreeze"}
         logger.debug(json.dumps(body))
         r = self._execute("PUT", f"/api/v1/qa/{qa_hash}", body=json.dumps(body))
-        logger.info("QA unfreezing initiated")
-        logger.debug(json.dumps(r.json(), indent=2))
+        self.handle_call_result(r, "unfreezing", qa_hash)
 
     def maintenance(self):
         r = self._execute("POST", "/api/v1/maintenance")
@@ -245,7 +242,7 @@ class QainitHandler:
         # pylint: disable-next=missing-timeout
         r = requests.request(request_method, api_url, headers=headers, data=body)
 
-        if 200 <= r.status_code <= 299:
+        if r.ok:
             logger.debug("Call to qainit-evo executed successfully")
         else:
             logger.error("Some issue during call to qainit-evo: ")
@@ -253,3 +250,10 @@ class QainitHandler:
             logger.debug(api_endpoint)
 
         return r
+
+    def handle_call_result(self, req, operation, qa_hash):
+        if req.ok:
+            logger.info(f"QA {operation} initiated")
+        else:
+            logger.debug(json.dumps(req.json(), indent=2))
+            logger.info(f"Run suite-py qa describe {qa_hash} to check the status")
