@@ -4,6 +4,7 @@ import re
 import time
 from urllib.parse import urljoin
 
+from suite_py.lib import logger
 from suite_py.lib.requests.auth import BearerAuth
 from suite_py.lib.requests.session import Session
 
@@ -28,11 +29,14 @@ class YoutrackHandler:
         return self._client.get("users/me", params=params).json()
 
     def get_issue(self, issue_id):
+        logger.debug(f"YouTrack issue_id: {issue_id}")
         params = {
             "fields": "$type,id,idReadable,summary,customFields(name,value(name))"
         }
         issue = self._client.get(f"issues/{issue_id}", params=params).json()
+        logger.debug(f"YouTrack Issue json {issue}")
         type_field = [x for x in issue["customFields"] if x["name"] == "Type"][0]
+        logger.debug(f"Youtrack Issue type_field {type_field}")
         issue["Type"] = type_field["value"]["name"]
         return issue
 
